#
# spec file for package thin-provisioning-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           thin-provisioning-tools
Version:        1.0.9
Release:        1.1
Summary:        Thin Provisioning Tools
License:        GPL-3.0-only
URL:            https://github.com/jthornber/thin-provisioning-tools/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  suse-module-tools
Requires(post): coreutils
Requires(postun):coreutils
Conflicts:      device-mapper < 1.02.115

%description
A suite of tools for thin provisioning on Linux.

%prep
%autosetup -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%post
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%doc README.md
%license COPYING
%{_bindir}/pdata_tools

%changelog
* Mon Dec 18 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.9:
  * Update Cargo.lock
  * [build] Check Cargo.lock while it is updated
  * Bump version to 1.0.9
  * [build] Sync dependencies versions between Cargo.lock and Cargo.toml
  * [thin_check] Extend the --clear-needs-check-flag option to have auto-repair caps
  * [build] Require that Cargo.lock is up to date
  * [all] Fix clippy lints for Rust 1.74.0
  * Update cargo.lock
  * bump version nr to 1.0.8
  * [sync io engine] Stop reusing the same gap buffer.
  * [tests] Fix extra arguments for IO tests
* Tue Nov 28 2023 Martin Pluskal <mpluskal@suse.com>
- Update vendored dependencies
* Tue Nov 14 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.7:
  * v1.0.7
  * [thin_generate_metadata] Fix command line parsing
  * [tests] Introduce era_generate_metadata
  * [era] Factor out MetadataGenerator
  * [era_invalidate] Fix missing value_parser for the --written-since option
  * [tests] Support additional program-specific arguments in IO tests
  * [examples] Add a custom emitter examples
  * Remove unnecesary type casting
  * [file_utils] Verify ioctl request code in tests
  * [file_utils] Fix the ioctl request code for the powerpc architecture
  * bump version to 1.0.6
  * [build] Update dependencies
  * [thin_delta] Remove redundant code
  * [thin_delta] Fix range mappings construction
  * [thin_delta] Fix command line parsing
  * [pack/unpack] Fix clippy lints
  * Bump version to v1.05
  * Add some test cases to delta_list
  * [pack/unpack]  Fix some wrapping issues
  * [tests] Ensure the scope of thin_check --super-block-only
  * [tests] Test repairing thin metadata with stale superblock
  * [thin_generate_damage] Support overriding superblock fields
  * [tests] Validate more fields in repaired thin superblock
  * [thin_explore] Fix visiting empty leaves
  * [xml] Improve xml value parsing and error handling
  * [all] Update error messages for xml parsers
  * [build] Update quick-xml to v0.29
  * [build] Update clap to v4.3
  * [build] Update dependencies
  * [thin_rmap] Check the input ranges
  * [thin_dump/repair] Fix the ordering of found empty roots
  * [report] Fix stderr redirection
  * [thin_dump/repair] Ensure the tools never fail with repairable metadata
  * [build] allow overriding PDATA_TOOLS in Makefile
  * [build] fix build on musl
  * [thin_stat] Display column headers and further statistics
  * [thin_stat] Display data run length statistics for measuring data locality
  * [thin_explore] Fix unit conversion for data block size
  * [thin_explore] Display space maps usage and roots
  * [thin_stat] Fix opening read-only files
  * [thin_dump] Fix a regression that cannot keep shared defs with only one predecessor
  * [commands] Print out error root cause if available
* Fri Jun  9 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.4:
  * Bump version to 1.0.4
  * [build] Update dependencies
  * [all] Fix clippy lints for Rust 1.69.0
  * [build] Drop the nix crate
  * [file_utils] Fix the BLKGETSIZE64 ioctl for 32-bit platoforms
  * [file_utils] Use stat64 explicitly to handle large files on 32-bit systems
  * [write_batcher] Fix compilation error on 32-bit platforms
* Wed Jun  9 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Link as position-independent executable (bsc#1184124).
* Thu Aug 20 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.9.0:
  * New support tools: thin_metadata_{pack,unpack}.
  * thin_check can now check metadata snapshots.
  * some metadata space map bug fixes.
  * thin_check --auto-repair
  * Stop thin_dump --repair/thin_repair ignoring under populated nodes.
- Drop no longer needed patches:
  * boost_168.patch
  * ft-lib_bcache-rename-raise-raise_.patch
* Tue Aug 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.8.5
  * Mostly internal changes
* Mon Aug  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix name clash with raise() from signal.h, add
  ft-lib_bcache-rename-raise-raise_.patch
* Wed May 29 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.8.3:
  * Mostly internal changes
* Fri Aug 17 2018 adam.majer@suse.de
- boost_168.patch: fix build with Boost 1.68. This version of Boost
  removes compatibility SHA1 header from Uuid library. (bsc#1105088)
* Thu May 31 2018 mpluskal@suse.com
- Update to version 0.7.6:
  * Mostly internal changes
* Wed Mar 14 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Wed Dec  6 2017 mpluskal@suse.com
- Update to version 0.7.5:
  * Fix a bug that stopped cache_restore working with metadata
    version 2.
* Tue Oct 17 2017 mpluskal@suse.com
- Update to version 0.7.4:
  * No changes provided for this release
* Mon Oct  9 2017 mpluskal@suse.com
- Update to version 0.7.3:
  * Misc internal changes
  * Updates to tests
* Mon Oct  2 2017 mpluskal@suse.com
- Update to version 0.7.2:
  * Misc internal changes
  * Updated documentation and manpages
* Tue Sep  5 2017 mpluskal@suse.com
- Update to version 0.7.1:
  * Misc internal changes
- Enable development tools building
* Mon Aug 28 2017 mmarek@suse.com
- Depend on coreutils for initrd macros (bsc#1055492).
* Sun Jun 18 2017 mpluskal@suse.com
- Update dependencies of scriplets (boo#1044823)
* Mon Jun 12 2017 mpluskal@suse.com
- Update to version 0.7.0:
  * boo#1043043 gh#jthornber/thin-provisioning-tools#79
  * Needed for working with latest lvm2
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Aug 18 2016 mpluskal@suse.com
- Update to version 0.6.3:
  * Update documentation
* Sun Jul 10 2016 mpluskal@suse.com
- Update to version 0.6.2:
  * Fix bug in thin_delta
  * Fix recent regression in thin_repair.
  * Force g++-98 dialect
  * Fix bug in thin_trim
* Thu Feb 11 2016 rguenther@suse.com
- Explicitely build with -std=gnu++98 to avoid all sorts of
  non-C++11 conforming code.
* Sat Feb  6 2016 mpluskal@suse.com
- Update to 0.6.1
  * enable builds with static cxx library
- Make building more verbose
* Fri Jan 29 2016 mpluskal@suse.com
- Conflict with device-mapper < 1.02.115 to avoid file conflicts
* Sun Jan 24 2016 mpluskal@suse.com
- Use optflags when building
- Install to /usr/sbin
- Do not strip installed binaries
- Use scriplets for initrd regeneration
* Fri Jan 22 2016 mpluskal@suse.com
- Update to 0.6.0
  * thin_ls
* Sun Sep 20 2015 mpluskal@suse.com
- Update to 0.5.6
  * era_invalidate may be run on live metadata if the
  - -metadata-snap option is given.
- Changes for 0.5.5
  * You may now give the --metadata_snap option to thin_delta
    without specifying where the snap is.
  * Update man pages to make it clearer that most tools shouldn't
    be run on live metadata.
  * Fix some bugs in the metadata reference counting for
    thin_check.
* Tue Jul 28 2015 mpluskal@suse.com
- Update to 0.5.3
  * thin_delta, thin_trim
  * --clear-needs-check flag for cache_check
  * space map checking for thin check
* Thu Apr 23 2015 mpluskal@suse.com
- Update to 0.4.1
* Wed Feb  6 2013 martin@pluskal.org
- Cleanup .spec
* Wed Feb  6 2013 martin@pluskal.org
- Add patch for ldflags - ldflags.patch
* Tue Jul 31 2012 fehr@suse.de
- Make initial version of package from version 0.1.5 of
  thin-provisioning-tools
